import { BaseSDK } from './sdk';
import { Router, ResponseType, StandardResponse, NavigateToNativePageType } from '@jolibox/types';

const NavigateToNativePageTypeTypes = ['openHistory'];
export class RouterSDK extends BaseSDK implements Router {
  async openSchema(schema: string) {
    const errMsg = this.canIUseIfThrow('router.openSchema');
    if (errMsg) {
      return errMsg;
    }
    return await this.commands.executeCommand('RouterSDK.openSchema', schema);
  }
  async openPage(url: string): Promise<
    StandardResponse<{
      webviewId: number;
    }>
  > {
    const errMsg = this.canIUseIfThrow('router.openPage');
    if (errMsg) {
      return errMsg;
    }
    return await this.commands.executeCommand('RouterSDK.openPage', url);
  }
  async closePage(webviewId: number) {
    const errMsg = this.canIUseIfThrow('router.closePage');
    if (errMsg) {
      return errMsg;
    }
    return await this.commands.executeCommand('RouterSDK.closePage', webviewId);
  }
  async interceptSystemExit(intercept: boolean) {
    const errMsg = this.canIUseIfThrow('router.interceptSystemExit');
    if (errMsg) {
      return errMsg;
    }
    return await this.commands.executeCommand('RouterSDK.interceptSystemExit', intercept);
  }

  async navigateToNativePage(path: string, params: Record<string, unknown>) {
    const errMsg = this.canIUseIfThrow('router.navigateToNativePage');
    if (errMsg) {
      return errMsg;
    }

    if (!NavigateToNativePageTypeTypes.includes(path)) {
      return {
        code: 'FAILURE' as ResponseType,
        message: 'invalid path'
      };
    }
    return await this.commands.executeCommand(
      'RouterSDK.navigateToNativePage',
      path as NavigateToNativePageType,
      params
    );
  }
}
